<%inherit file="base.html"/>
<%def name="head()">

</%def>
<%def name="body()">
<div class="panel panel-default">
    <div class="panel-heading"><span class="glyphicon glyphicon-th"></span> 系统信息 </div>
        <div class="panel-body">
            <form class="form-horizontal form-well" role="form" action="/param" method="post">
                ${form.render_css()}
            </form>
        </div>
    </div>
</div>
</%def>